<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:src ="http://purl.oclc.org/dsdl/9573-11amd1/ns/structure/1.0" version="1.0">
  <xsl:template name="frontm">
    <fo:block break-before="page">
      <xsl:apply-templates select="/src:document/src:head" mode="frontm"/>
    </fo:block>
  </xsl:template>
  <xsl:template match="src:head" mode="frontm">
    <fo:table table-layout="fixed">
      <fo:table-column column-width="180pt"/>
      <fo:table-column column-width="230pt"/>
      <fo:table-column column-width="100pt"/>
      <fo:table-body>
        <fo:table-row height="90pt">
          <fo:table-cell number-rows-spanned="11"/>
          <fo:table-cell number-rows-spanned="2">
            <fo:block font-size="20pt" line-height="24pt">
              <xsl:call-template name="docstat">
                <xsl:with-param name="status" select="$dstat"/>
              </xsl:call-template>
            </fo:block>
          </fo:table-cell>
          <fo:table-cell>
            <fo:block text-align="right">
              <fo:block font-weight="bold" font-size="20pt" line-height="24pt">
                <xsl:value-of select="substring-before($dcode, ' ')"/>
              </fo:block>
              <fo:block font-weight="bold" font-size="20pt" line-height="24pt">
                <xsl:value-of select="substring-after($dcode, ' ')"/>
              </fo:block>
            </fo:block>
          </fo:table-cell>
        </fo:table-row>
        <fo:table-row height="120pt">
          <fo:table-cell>
            <fo:block text-align="right" font-size="9pt" line-height="10pt">
              <fo:block>
                <xsl:value-of select="src:edition"/>
                <xsl:call-template name="edstr">
                  <xsl:with-param name="lang" select="$lng"/>
                </xsl:call-template>
              </fo:block>
              <fo:block>
                <xsl:value-of select="src:date"/>
              </fo:block>
            </fo:block>
          </fo:table-cell>
        </fo:table-row>
        <fo:table-row height="1.5pt">
          <fo:table-cell number-columns-spanned="2" border-top-style="solid"/>
        </fo:table-row>
        <fo:table-row height="1.5pt">
          <fo:table-cell number-columns-spanned="2" border-top-style="solid"/>
        </fo:table-row>
        <fo:table-row height="1.5pt">
          <fo:table-cell number-columns-spanned="2" border-top-style="solid"/>
        </fo:table-row>
        <fo:table-row height="460pt">
          <fo:table-cell number-columns-spanned="2">
            <fo:block xsl:use-attribute-sets="ttl">
              <xsl:apply-templates select="src:title[@langcode=$lng]" mode="frontm"/>
            </fo:block>
            <fo:block xsl:use-attribute-sets="p" font-style="italic">
              <xsl:apply-templates select="src:title[@langcode!=$lng]" mode="frontm"/>
            </fo:block>
          </fo:table-cell>
        </fo:table-row>
        <fo:table-row height="1.5pt">
          <fo:table-cell number-columns-spanned="2" border-top-style="solid"/>
        </fo:table-row>
        <fo:table-row height="1.5pt">
          <fo:table-cell number-columns-spanned="2" border-top-style="solid"/>
        </fo:table-row>
        <fo:table-row height="1.5pt">
          <fo:table-cell number-columns-spanned="2" border-top-style="solid"/>
        </fo:table-row>
        <fo:table-row height="60pt">
          <fo:table-cell number-rows-spanned="2"/>
          <fo:table-cell>
            <fo:block text-align="right" font-size="9pt" space-before=".5em">
              <fo:block>
                <xsl:call-template name="refstr">
                  <xsl:with-param name="lang" select="$lng"/>
                </xsl:call-template>
              </fo:block>
              <fo:block>
                <xsl:call-template name="refnum"/>
              </fo:block>
            </fo:block>
          </fo:table-cell>
        </fo:table-row>
        <fo:table-row height="10pt">
          <fo:table-cell>
            <fo:block text-align="right">
              <xsl:text>&#169; </xsl:text>
              <xsl:value-of select="substring-before($dcode, ' ')"/>
              <xsl:text> </xsl:text>
              <xsl:value-of select="$year"/>
            </fo:block>
          </fo:table-cell>
        </fo:table-row>
      </fo:table-body>
    </fo:table>
  </xsl:template>
  <xsl:template match="src:title" mode="frontm">
    <xsl:if test="src:introductory">
      <fo:block>
        <xsl:apply-templates select="src:introductory"/>
      </fo:block>
    </xsl:if>
    <fo:block space-after=".5em">
      <xsl:apply-templates select="src:main"/>
    </fo:block>
    <xsl:if test="src:complementary">
      <fo:block font-weight="normal">
        <xsl:call-template name="part">
          <xsl:with-param name="lang" select="@langcode"/>
        </xsl:call-template>
        <xsl:text> </xsl:text>
        <xsl:value-of select="../src:part-number"/>
        <xsl:text>:</xsl:text>
      </fo:block>
      <fo:block>
        <xsl:apply-templates select="src:complementary"/>
      </fo:block>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>